@@ -17,7 +17,7 @@ use Term::ProgressBar;
 
 my $cpants='Module::CPANTS::Generator';
 $cpants->setup_dirs;
-$cpants->load_generators([qw(Unpack Files Pod Prereq CPAN)]);
+$cpants->load_generators;
 
 my $DBH=DBI->connect("dbi:SQLite:dbname=cpants.db");
 $cpants->DBH($DBH);
@@ -29,7 +29,7 @@ my @files=grep {/\.yml$/} readdir(DIR);
 my $progress=Term::ProgressBar->new({
 				     name=>'Complex Kwalitee',
 				     count=>scalar @files,
-				    });
+				    }) unless $cpants->conf->no_bar;
 
 foreach my $f (@files) {
     chomp($f);
@@ -38,7 +38,7 @@ foreach my $f (@files) {
     $cpants->determine_kwalitee('complex',$metric);
     $cpants->write_metric($metric);
 
-    $progress->update();
+    $progress->update() unless $cpants->conf->no_bar;
 }
 
 
